:mod:`art.defences.detector.evasion`
====================================
.. automodule:: art.defences.detector.evasion

Base Class
------------------------
.. autoclass:: EvasionDetector
   :members:

Binary Input Detector
---------------------
.. autoclass:: BinaryInputDetector
   :members:

Binary Activation Detector
--------------------------
.. autoclass:: BinaryActivationDetector
   :members:

Subset Scanning Detector
------------------------
.. autoclass:: SubsetScanningDetector
   :members:
